==> zio-aws-ec2_2.12-5.20.7.3-sources.jar: zio/aws/ec2/model/GetIpamDiscoveredAccountsRequest.scala <==
package zio.aws.ec2.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.ec2.model.primitives.{
  IpamMaxResults,
  NextToken,
  IpamResourceDiscoveryId
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class GetIpamDiscoveredAccountsRequest(
    ipamResourceDiscoveryId: IpamResourceDiscoveryId,
    discoveryRegion: String,
    filters: Optional[Iterable[zio.aws.ec2.model.Filter]] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent,
    maxResults: Optional[IpamMaxResults] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.GetIpamDiscoveredAccountsRequest = {
    import GetIpamDiscoveredAccountsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.GetIpamDiscoveredAccountsRequest
      .builder()
      .ipamResourceDiscoveryId(
        IpamResourceDiscoveryId.unwrap(
          ipamResourceDiscoveryId
        ): java.lang.String
      )
      .discoveryRegion(discoveryRegion: java.lang.String)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => IpamMaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.GetIpamDiscoveredAccountsRequest.ReadOnly =
    zio.aws.ec2.model.GetIpamDiscoveredAccountsRequest.wrap(buildAwsValue())
}
object GetIpamDiscoveredAccountsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.GetIpamDiscoveredAccountsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.GetIpamDiscoveredAccountsRequest =
      zio.aws.ec2.model.GetIpamDiscoveredAccountsRequest(
        ipamResourceDiscoveryId,
        discoveryRegion,
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def ipamResourceDiscoveryId: IpamResourceDiscoveryId
    def discoveryRegion: String
    def filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]]
    def nextToken: Optional[NextToken]
    def maxResults: Optional[IpamMaxResults]
    def getIpamResourceDiscoveryId: ZIO[Any, Nothing, IpamResourceDiscoveryId] =
      ZIO.succeed(ipamResourceDiscoveryId)
    def getDiscoveryRegion: ZIO[Any, Nothing, String] =
      ZIO.succeed(discoveryRegion)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, IpamMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.GetIpamDiscoveredAccountsRequest
  ) extends zio.aws.ec2.model.GetIpamDiscoveredAccountsRequest.ReadOnly {
    override val ipamResourceDiscoveryId: IpamResourceDiscoveryId =
      zio.aws.ec2.model.primitives
        .IpamResourceDiscoveryId(impl.ipamResourceDiscoveryId())
    override val discoveryRegion: String = impl.discoveryRegion(): String
    override val filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.Filter.wrap(item)
          }.toList
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.ec2.model.primitives.NextToken(value))
    override val maxResults: Optional[IpamMaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.ec2.model.primitives.IpamMaxResults(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.GetIpamDiscoveredAccountsRequest
  ): zio.aws.ec2.model.GetIpamDiscoveredAccountsRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.12-7.21.15.7-sources.jar: zio/aws/ec2/model/GetIpamDiscoveredAccountsRequest.scala <==
package zio.aws.ec2.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.ec2.model.primitives.{
  IpamMaxResults,
  NextToken,
  IpamResourceDiscoveryId
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class GetIpamDiscoveredAccountsRequest(
    dryRun: Optional[Boolean] = Optional.Absent,
    ipamResourceDiscoveryId: IpamResourceDiscoveryId,
    discoveryRegion: String,
    filters: Optional[Iterable[zio.aws.ec2.model.Filter]] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent,
    maxResults: Optional[IpamMaxResults] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.GetIpamDiscoveredAccountsRequest = {
    import GetIpamDiscoveredAccountsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.GetIpamDiscoveredAccountsRequest
      .builder()
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .ipamResourceDiscoveryId(
        IpamResourceDiscoveryId.unwrap(
          ipamResourceDiscoveryId
        ): java.lang.String
      )
      .discoveryRegion(discoveryRegion: java.lang.String)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => IpamMaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.GetIpamDiscoveredAccountsRequest.ReadOnly =
    zio.aws.ec2.model.GetIpamDiscoveredAccountsRequest.wrap(buildAwsValue())
}
object GetIpamDiscoveredAccountsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.GetIpamDiscoveredAccountsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.GetIpamDiscoveredAccountsRequest =
      zio.aws.ec2.model.GetIpamDiscoveredAccountsRequest(
        dryRun.map(value => value),
        ipamResourceDiscoveryId,
        discoveryRegion,
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def dryRun: Optional[Boolean]
    def ipamResourceDiscoveryId: IpamResourceDiscoveryId
    def discoveryRegion: String
    def filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]]
    def nextToken: Optional[NextToken]
    def maxResults: Optional[IpamMaxResults]
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
    def getIpamResourceDiscoveryId: ZIO[Any, Nothing, IpamResourceDiscoveryId] =
      ZIO.succeed(ipamResourceDiscoveryId)
    def getDiscoveryRegion: ZIO[Any, Nothing, String] =
      ZIO.succeed(discoveryRegion)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, IpamMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.GetIpamDiscoveredAccountsRequest
  ) extends zio.aws.ec2.model.GetIpamDiscoveredAccountsRequest.ReadOnly {
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
    override val ipamResourceDiscoveryId: IpamResourceDiscoveryId =
      zio.aws.ec2.model.primitives
        .IpamResourceDiscoveryId(impl.ipamResourceDiscoveryId())
    override val discoveryRegion: String = impl.discoveryRegion(): String
    override val filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.Filter.wrap(item)
          }.toList
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.ec2.model.primitives.NextToken(value))
    override val maxResults: Optional[IpamMaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.ec2.model.primitives.IpamMaxResults(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.GetIpamDiscoveredAccountsRequest
  ): zio.aws.ec2.model.GetIpamDiscoveredAccountsRequest.ReadOnly = new Wrapper(
    impl
  )
}
